"""Add container image environment variables

Revision ID: cb86ec08e5ce
Revises: 081bee0d9587
Create Date: 2021-03-09 11:39:07.315261+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'cb86ec08e5ce'
down_revision = '081bee0d9587'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('external_software_environment', sa.Column('env_image_name', sa.Text(), nullable=True))
    op.add_column('external_software_environment', sa.Column('env_image_tag', sa.Text(), nullable=True))
    op.add_column('software_environment', sa.Column('env_image_name', sa.Text(), nullable=True))
    op.add_column('software_environment', sa.Column('env_image_tag', sa.Text(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('software_environment', 'env_image_tag')
    op.drop_column('software_environment', 'env_image_name')
    op.drop_column('external_software_environment', 'env_image_tag')
    op.drop_column('external_software_environment', 'env_image_name')
    # ### end Alembic commands ###



"""Introduce Thoth specific entries found in the container image

Revision ID: b957aa9cce3e
Revises: 91620576525b
Create Date: 2021-01-28 06:59:01.137118+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'b957aa9cce3e'
down_revision = '91620576525b'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('package_extract_run', sa.Column('thoth_s2i_image_name', sa.Text(), nullable=True))
    op.add_column('package_extract_run', sa.Column('thoth_s2i_image_version', sa.Text(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('package_extract_run', 'thoth_s2i_image_version')
    op.drop_column('package_extract_run', 'thoth_s2i_image_name')
    # ### end Alembic commands ###



"""Move Thoth s2i information to software environment

Revision ID: f1824f0c1afa
Revises: b957aa9cce3e
Create Date: 2021-01-29 08:10:11.514624+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'f1824f0c1afa'
down_revision = 'b957aa9cce3e'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('external_software_environment', sa.Column('thoth_s2i_image_name', sa.Text(), nullable=True))
    op.add_column('external_software_environment', sa.Column('thoth_s2i_image_version', sa.Text(), nullable=True))
    op.drop_column('package_extract_run', 'thoth_s2i_image_name')
    op.drop_column('package_extract_run', 'thoth_s2i_image_version')
    op.add_column('software_environment', sa.Column('thoth_s2i_image_name', sa.Text(), nullable=True))
    op.add_column('software_environment', sa.Column('thoth_s2i_image_version', sa.Text(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('software_environment', 'thoth_s2i_image_version')
    op.drop_column('software_environment', 'thoth_s2i_image_name')
    op.add_column('package_extract_run', sa.Column('thoth_s2i_image_version', sa.TEXT(), autoincrement=False, nullable=True))
    op.add_column('package_extract_run', sa.Column('thoth_s2i_image_name', sa.TEXT(), autoincrement=False, nullable=True))
    op.drop_column('external_software_environment', 'thoth_s2i_image_version')
    op.drop_column('external_software_environment', 'thoth_s2i_image_name')
    # ### end Alembic commands ###
